Field | Type | Description
--- | --- | ---
background | Background | To-Do
background-clip | Origin | To-Do
background-color | Brush | To-Do
border | Border | To-Do
border-top | Border | To-Do
border-right | Border | To-Do
border-bottom | Border | To-Do
border-left | Border | To-Do
border-color | Box Colors | To-Do
border-top-color | Brush | To-Do
border-right-color | Brush | To-Do
border-bottom-color | Brush | To-Do
border-left-color | Brush | To-Do
border-radius | Radius | To-Do
border-top-left-radius | Radius | To-Do
border-top-right-radius | Radius | To-Do
border-bottom-right-radius | Radius | To-Do
border-bottom-left-radius | Radius | To-Do
border-style | Border Style | To-Do
border-top-style | Border Style | To-Do
border-right-style | Border Style | To-Do
border-bottom-style | Border Style | To-Do
border-left-style | Border Style | To-Do
border-width | Box Lengths | To-Do
border-top-width | Length | To-Do
border-right-width | Length | To-Do
border-bottom-width | Length | To-Do
border-left-width | Length | To-Do
bottom | Length | To-Do
color | Brush | To-Do
font | Font | To-Do
font-family | String | To-Do
font-size | Font Size | To-Do
font-style | Font Style | To-Do
font-weight | Font Weight | To-Do
height | Length | To-Do
icon-size | Length | To-Do
left | Length | To-Do
line-edit-password-character | Number | To-Do
margin | Box Lengths | To-Do
margin-top | Length | To-Do
margin-right | Length | To-Do
margin-bottom | Length | To-Do
margin-left | Length | To-Do
max-height | Length | To-Do
max-width | Length | To-Do
min-height | Length | To-Do
min-width | Length | To-Do
padding | Box Lengths | To-Do
padding-top | Length | To-Do
padding-right | Length | To-Do
padding-bottom | Length | To-Do
padding-left | Length | To-Do
position | relative | absolute | To-Do
right | Length | To-Do
selection-background-color | Brush | To-Do
selection-color | Brush | To-Do
spacing | Length | To-Do
subcontrol-origin | Origin | To-Do
subcontrol-position | Alignment | To-Do
text-align | Alignment | To-Do
text-decoration | none underline overline line-through | To-Do
top | Length | To-Do
width | Length | To-Do